@@ -1,14 +1,14 @@
-# Copyrights 2001-2019 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Mail-Box.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Mail::Box::Dir;
-use vars '$VERSION';
-$VERSION = '3.007';
+package Mail::Box::Dir;{
+our $VERSION = '3.011';
+}
 
 use base 'Mail::Box';
 
@@ -103,7 +103,15 @@ sub folderToDirectory($$)
     $dir;
 }
 
-#-------------------------------------------
+sub storeMessage($)
+{   my ($self, $message) = @_;
+    $self->SUPER::storeMessage($message);
+    my $fn = $message->filename or return $message;
+    $self->{MBD_by_fn}{$fn} = $message;
+}
+
+
+sub messageInFile($) { $_[0]->{MBD_by_fn}{$_[1]} }
 
 
 sub readMessageFilenames() {shift->notImplemented}
